@@ -70,6 +70,10 @@ def parse_args():
                         "existing directories rather, than assuming to create "
                         "them; for example if ensemble has previously failed",
                         default=False, action="store_true")
+    parser.add_argument("-l", "--shell",
+                        help="Allows the user to specify the shell passed to "
+                             "subprocess execs.",
+                        default="/bin/bash", type=str)
 
     # FIXME: These should not be applied in multi-batch ensembles
     parser.add_argument("-k", "--skips",
@@ -80,9 +84,9 @@ def parse_args():
                         help="Specify which indexes to run",
                         type=parse_indexes)
 
-    parser.add_argument("-ct", "--check-timeout", default=10, type=int)
-    parser.add_argument("-st", "--submit-timeout", default=10, type=int)
-    parser.add_argument("-rt", "--running-timeout", default=10, type=int)
+    parser.add_argument("-ct", "--check-timeout", default=30, type=int)
+    parser.add_argument("-st", "--submit-timeout", default=20, type=int)
+    parser.add_argument("-rt", "--running-timeout", default=60, type=int)
     parser.add_argument("-et", "--error-timeout", default=120, type=int)
 
     parser.add_argument("-ms", "--max-stagger", default=1, type=int)
@@ -113,6 +117,7 @@ def main():
     logging.info("Model Ensemble Runner")
 
     config = EnsembleConfig(args.configuration)
+    # TODO: get_batch_executor
     BatchExecutor(config,
                   args.backend,
                   dict(args.extra)).run()
